pub struct QuantizedVector {
pub binary_code_packed: Vec<u8>,
pub ex_code_packed: Vec<u8>,
pub ex_bits: u8,
pub dim: usize,
pub delta: f32,
pub vl: f32,
pub f_add: f32,
pub f_rescale: f32,
pub f_error: f32,
pub residual_norm: f32,
pub f_add_ex: f32,
pub f_rescale_ex: f32,
}Expand description
Quantised representation of a vector using packed format (aligned with C++ implementation).
Binary codes and extended codes are stored in bit-packed format for memory efficiency.
binary_code_packed: 1 bit per dimensionex_code_packed: ex_bits per dimension
For performance-critical search operations, unpacked codes are cached to avoid repeated unpacking overhead.
Fields
binary_code_packed: Vec<u8>Packed binary code (1 bit per element)
ex_code_packed: Vec<u8>Packed extended code (ex_bits per element)
ex_bits: u8Number of extended bits per element
dim: usizeOriginal dimension (before padding)
delta: f32vl: f32f_add: f32f_rescale: f32f_error: f32residual_norm: f32f_add_ex: f32f_rescale_ex: f32Implementations
Sourceimpl QuantizedVector
impl QuantizedVector
Sourcepub fn unpack_binary_code(&self) -> Vec<u8> ⓘ
pub fn unpack_binary_code(&self) -> Vec<u8> ⓘ
Unpack binary code for computation
Sourcepub fn unpack_ex_code(&self) -> Vec<u16>
pub fn unpack_ex_code(&self) -> Vec<u16>
Unpack extended code for computation
Sourcepub fn ensure_unpacked_cache(&mut self)
pub fn ensure_unpacked_cache(&mut self)
Ensure unpacked caches are populated (No-op in memory-optimized version)